Search.setIndex({envversion:42,terms:{scm:2,all:2,identifi:2,help:2,execut:3,less:[],thi:[3,2],over:0,global:2,obtain:2,collabor:[],prefix:2,own:[0,2],privileg:[0,1],permiss:3,follow:[3,2],comput:[3,2],access:[0,3,2],privat:[0,3,2],password:[],locat:2,just:3,easi:[],also:3,wget:2,usernam:[3,2],send:[],should:[3,2],identif:2,add:3,pend:[],present:2,under:2,mail:2,sent:3,bin:2,sourc:2,proced:2,thei:[0,3],get:[],python:2,pypi:2,initi:1,util:[],ssh:[0,3,2],now:2,nor:2,name:[0,3,2],administr:[0,2],list:0,authent:2,email:[3,2],remot:[0,1,3],contain:3,output:2,where:[3,2],page:[],dir:3,user:[0,2],set:[],replac:[3,2],some:[3,2],continu:2,see:2,design:[0,1,2],connect:[],download:2,recogn:3,ommit:2,alia:[3,2],append:2,after:3,even:2,awar:2,what:[],section:2,abl:3,henceforth:3,rewrit:[],state:3,version:2,between:0,print:2,"import":2,"public":3,refer:3,machin:[3,2],core:[],full:2,kei:[0,3],each:0,onli:[3,2],here:2,reason:2,let:[0,3,2],repositori:[0,1,2],address:[3,2],depend:2,sinc:2,bash:2,search:[],last:[3,2],invit:0,admin:[1,2],howev:2,host:[3,2],acl:0,amount:3,name_of_repositori:3,promou:3,typic:3,write_authorized_kei:[],com:2,think:2,first:[3,2],via:[0,3],simpli:[3,2],point:2,onc:3,number:2,yourself:2,down:0,bashrc:2,instruct:3,alreadi:3,done:[3,2],path:2,instal:[],assum:[3,2],your:[0,3,2],manag:[0,1],given:[3,2],git:[],from:[3,2],creat:[0,1,2,3],wai:[],script:[],unknown:[],system:[],been:3,next:2,avail:2,start:[],includ:[3,2],easiest:2,time:2,butler:0,getuserbas:2,store:2,more:[0,2],shell:2,desir:3,option:[3,2],fire:2,copi:2,about:2,specifi:[0,3],site:2,link:3,line:2,hold:3,than:2,behalf:3,must:2,"case":2,account:[0,3,2],init:3,provid:[3,2],wish:[3,2],setup:2,work:[3,2],requir:3,project:0,directori:[3,2],limit:3,can:[3,2],"export":2,inform:2,server:[],control:0,xvzf:2,prompt:3,have:[0,3,2],tar:2,readi:2,request:[],sudo:2,mind:2,argument:3,accept:[],packag:2,minimum:3,right:2,file:[3,2],pip:2,exist:3,keep:2,minu:3,sever:3,alwai:3,goal:[0,2],want:3,author:[],perform:2,make:2,when:2,who:0,write:0,how:3,need:[0,1,2,3],read:2,which:[0,3,2],verifi:2,you:[0,3,2],complet:2,blutler:[],sure:2,http:2,hostnam:[3,2],shall:3,passwordless:3,org:2,previou:2,nix:[],befor:2,mac:3,temporari:3,two:2,mai:[0,3,2],unless:2,ani:[3,2],scenario:3,choos:2,privilag:3,well:2,read_authorized_kei:[],bash_profil:2,person:[0,3,2],without:[0,1,2],command:[3,2],allow:[0,3,2],enter:2,differ:2,know:3},objtypes:{},objnames:{},filenames:["promus","index","installation","start"],titles:["What is Promus?","Promus Documentation","Installing Promus","Getting Started"],objects:{},titleterms:{set:2,less:3,accept:3,collabor:3,connect:3,instal:2,what:0,git:2,wai:2,script:2,system:2,send:3,start:3,basic:1,document:1,get:3,usag:1,initi:3,nix:2,repositori:3,password:3,easi:2,request:3,promu:[0,1,2],server:3}})